#ifdef GL_ES
    #define LOWP lowp
    precision mediump float;
#else
    #define LOWP
#endif

varying vec2 v_texCoords;
uniform sampler2D u_texture0;
uniform vec2 u_viewport;
uniform vec2 u_center;
uniform float u_intensity;
uniform float u_safeRadius;
uniform float u_fadeRadius;
uniform vec3 u_tint;

float lerp(float start, float end, float progress) {
    return start + progress * (end - start);
}

float square(float value) {
    return value * value;
}

void main() {
    vec4 col = texture2D(u_texture0, v_texCoords);


    vec2 cenPoint = u_center / u_viewport;
    float dist = sqrt(square(cenPoint.x - v_texCoords.x) + square((cenPoint.y - v_texCoords.y) * u_viewport.y/u_viewport.x));
    float safeRadius = u_safeRadius / u_viewport.x;
    float fadeRadius = u_fadeRadius / u_viewport.x;
    float distFactor = clamp((dist - safeRadius) / (fadeRadius - safeRadius), 0.0, 0.95);

    vec4 colMutated = vec4(col.r * 0.3 + col.g * 0.59 + col.b * 0.11);
    colMutated.a = 1.0;
    colMutated.rgb = mix(colMutated.rgb, colMutated.rgb * u_tint, distFactor);
    col = mix(col, colMutated, u_intensity);
    col = mix(col, vec4(u_tint * 0.1, 1.0), distFactor);

    gl_FragColor = col;
}